@@ -1,5 +1,5 @@
 package Net::Google::CalendarV3::Date;
-$Net::Google::CalendarV3::Date::VERSION = '0.11';
+$Net::Google::CalendarV3::Date::VERSION = '0.12';
 use Moose;
 use Kavorka;
 use DateTime::Format::ISO8601;
@@ -14,7 +14,7 @@ method set (DateTime $dt, CBool $is_all_day) {
         $self->clear_timeZone;
     } else {
         $self->dateTime($dt->iso8601);
-        $self->timeZone($dt->time_zone->name) if $dt->time_zone && $dt->time_zone ne 'floating';
+        $self->timeZone($dt->time_zone->name) if $dt->time_zone && !$dt->time_zone->is_floating;
         $self->clear_date;
     }
 }
